/*
 * This file is part of SubLib.
 * Copyright (C) 2007-2010 Pedro Castro
 *
 * SubLib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * SubLib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

using SubLib.Core.Domain;

namespace SubLib.IO.Input {

internal class ParsingProperties {
	private Headers headers = new Headers();
	private TimingMode timingMode = TimingMode.Times;
	private float inputFrameRate = 25;
	
	public Headers Headers {
		get { return headers; }
	}
	
	public TimingMode TimingMode {
		get { return timingMode; }
		set { timingMode = value; }
	}
	
	public float InputFrameRate {
		get { return inputFrameRate; }
		set { inputFrameRate = value; }
	}

}

}